# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_buttons.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName(_fromUtf8("DockWidget"))
        DockWidget.resize(527, 460)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label_72 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_72.setFont(font)
        self.label_72.setObjectName(_fromUtf8("label_72"))
        self.gridLayout.addWidget(self.label_72, 0, 1, 1, 1)
        self.label_73 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_73.setFont(font)
        self.label_73.setObjectName(_fromUtf8("label_73"))
        self.gridLayout.addWidget(self.label_73, 0, 2, 1, 1)
        self.label_26 = QtGui.QLabel(self.dockWidgetContents)
        self.label_26.setMinimumSize(QtCore.QSize(0, 0))
        self.label_26.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_26.setFont(font)
        self.label_26.setObjectName(_fromUtf8("label_26"))
        self.gridLayout.addWidget(self.label_26, 1, 0, 1, 1)
        self.pushButton = QtGui.QPushButton(self.dockWidgetContents)
        self.pushButton.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton.setObjectName(_fromUtf8("pushButton"))
        self.gridLayout.addWidget(self.pushButton, 1, 1, 1, 1)
        self.pushButtonDis = QtGui.QPushButton(self.dockWidgetContents)
        self.pushButtonDis.setEnabled(False)
        self.pushButtonDis.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButtonDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButtonDis.setDefault(False)
        self.pushButtonDis.setObjectName(_fromUtf8("pushButtonDis"))
        self.gridLayout.addWidget(self.pushButtonDis, 1, 2, 1, 1)
        self.label_74 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_74.setFont(font)
        self.label_74.setObjectName(_fromUtf8("label_74"))
        self.gridLayout.addWidget(self.label_74, 2, 0, 1, 1)
        self.pushButtonChecked = QtGui.QPushButton(self.dockWidgetContents)
        self.pushButtonChecked.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButtonChecked.setCheckable(True)
        self.pushButtonChecked.setChecked(True)
        self.pushButtonChecked.setObjectName(_fromUtf8("pushButtonChecked"))
        self.gridLayout.addWidget(self.pushButtonChecked, 2, 1, 1, 1)
        self.pushButtonCheckedDis = QtGui.QPushButton(self.dockWidgetContents)
        self.pushButtonCheckedDis.setEnabled(False)
        self.pushButtonCheckedDis.setCheckable(True)
        self.pushButtonCheckedDis.setChecked(True)
        self.pushButtonCheckedDis.setObjectName(_fromUtf8("pushButtonCheckedDis"))
        self.gridLayout.addWidget(self.pushButtonCheckedDis, 2, 2, 1, 1)
        self.label_76 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_76.setFont(font)
        self.label_76.setObjectName(_fromUtf8("label_76"))
        self.gridLayout.addWidget(self.label_76, 3, 0, 1, 1)
        self.pushButtonUnchecked = QtGui.QPushButton(self.dockWidgetContents)
        self.pushButtonUnchecked.setCheckable(True)
        self.pushButtonUnchecked.setObjectName(_fromUtf8("pushButtonUnchecked"))
        self.gridLayout.addWidget(self.pushButtonUnchecked, 3, 1, 1, 1)
        self.pushButtonUncheckedDis = QtGui.QPushButton(self.dockWidgetContents)
        self.pushButtonUncheckedDis.setEnabled(False)
        self.pushButtonUncheckedDis.setCheckable(True)
        self.pushButtonUncheckedDis.setObjectName(_fromUtf8("pushButtonUncheckedDis"))
        self.gridLayout.addWidget(self.pushButtonUncheckedDis, 3, 2, 1, 1)
        self.label_33 = QtGui.QLabel(self.dockWidgetContents)
        self.label_33.setMinimumSize(QtCore.QSize(0, 0))
        self.label_33.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_33.setFont(font)
        self.label_33.setObjectName(_fromUtf8("label_33"))
        self.gridLayout.addWidget(self.label_33, 4, 0, 1, 1)
        self.toolButton = QtGui.QToolButton(self.dockWidgetContents)
        self.toolButton.setMinimumSize(QtCore.QSize(0, 0))
        self.toolButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.toolButton.setObjectName(_fromUtf8("toolButton"))
        self.gridLayout.addWidget(self.toolButton, 4, 1, 1, 1)
        self.toolButtonDis = QtGui.QToolButton(self.dockWidgetContents)
        self.toolButtonDis.setEnabled(False)
        self.toolButtonDis.setMinimumSize(QtCore.QSize(0, 0))
        self.toolButtonDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.toolButtonDis.setObjectName(_fromUtf8("toolButtonDis"))
        self.gridLayout.addWidget(self.toolButtonDis, 4, 2, 1, 1)
        self.label_75 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_75.setFont(font)
        self.label_75.setObjectName(_fromUtf8("label_75"))
        self.gridLayout.addWidget(self.label_75, 5, 0, 1, 1)
        self.radioButtonChecked = QtGui.QRadioButton(self.dockWidgetContents)
        self.radioButtonChecked.setChecked(True)
        self.radioButtonChecked.setAutoExclusive(False)
        self.radioButtonChecked.setObjectName(_fromUtf8("radioButtonChecked"))
        self.gridLayout.addWidget(self.radioButtonChecked, 5, 1, 1, 1)
        self.radioButtonCheckedDis = QtGui.QRadioButton(self.dockWidgetContents)
        self.radioButtonCheckedDis.setEnabled(False)
        self.radioButtonCheckedDis.setChecked(True)
        self.radioButtonCheckedDis.setAutoExclusive(False)
        self.radioButtonCheckedDis.setObjectName(_fromUtf8("radioButtonCheckedDis"))
        self.gridLayout.addWidget(self.radioButtonCheckedDis, 5, 2, 1, 1)
        self.label_29 = QtGui.QLabel(self.dockWidgetContents)
        self.label_29.setMinimumSize(QtCore.QSize(0, 0))
        self.label_29.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_29.setFont(font)
        self.label_29.setObjectName(_fromUtf8("label_29"))
        self.gridLayout.addWidget(self.label_29, 6, 0, 1, 1)
        self.radioButtonUnchecked = QtGui.QRadioButton(self.dockWidgetContents)
        self.radioButtonUnchecked.setMinimumSize(QtCore.QSize(0, 0))
        self.radioButtonUnchecked.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.radioButtonUnchecked.setAutoExclusive(False)
        self.radioButtonUnchecked.setObjectName(_fromUtf8("radioButtonUnchecked"))
        self.gridLayout.addWidget(self.radioButtonUnchecked, 6, 1, 1, 1)
        self.radioButtonUncheckedDis = QtGui.QRadioButton(self.dockWidgetContents)
        self.radioButtonUncheckedDis.setEnabled(False)
        self.radioButtonUncheckedDis.setMinimumSize(QtCore.QSize(0, 0))
        self.radioButtonUncheckedDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.radioButtonUncheckedDis.setChecked(False)
        self.radioButtonUncheckedDis.setAutoExclusive(False)
        self.radioButtonUncheckedDis.setObjectName(_fromUtf8("radioButtonUncheckedDis"))
        self.gridLayout.addWidget(self.radioButtonUncheckedDis, 6, 2, 1, 1)
        self.label_53 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_53.setFont(font)
        self.label_53.setObjectName(_fromUtf8("label_53"))
        self.gridLayout.addWidget(self.label_53, 7, 0, 1, 1)
        self.checkBoxChecked = QtGui.QCheckBox(self.dockWidgetContents)
        self.checkBoxChecked.setChecked(True)
        self.checkBoxChecked.setObjectName(_fromUtf8("checkBoxChecked"))
        self.gridLayout.addWidget(self.checkBoxChecked, 7, 1, 1, 1)
        self.checkBoxCheckedDis = QtGui.QCheckBox(self.dockWidgetContents)
        self.checkBoxCheckedDis.setEnabled(False)
        self.checkBoxCheckedDis.setChecked(True)
        self.checkBoxCheckedDis.setObjectName(_fromUtf8("checkBoxCheckedDis"))
        self.gridLayout.addWidget(self.checkBoxCheckedDis, 7, 2, 1, 1)
        self.label_30 = QtGui.QLabel(self.dockWidgetContents)
        self.label_30.setMinimumSize(QtCore.QSize(0, 0))
        self.label_30.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_30.setFont(font)
        self.label_30.setObjectName(_fromUtf8("label_30"))
        self.gridLayout.addWidget(self.label_30, 8, 0, 1, 1)
        self.checkBoxEnabled = QtGui.QCheckBox(self.dockWidgetContents)
        self.checkBoxEnabled.setMinimumSize(QtCore.QSize(0, 0))
        self.checkBoxEnabled.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.checkBoxEnabled.setTristate(False)
        self.checkBoxEnabled.setObjectName(_fromUtf8("checkBoxEnabled"))
        self.gridLayout.addWidget(self.checkBoxEnabled, 8, 1, 1, 1)
        self.checkBoxUncheckedDis = QtGui.QCheckBox(self.dockWidgetContents)
        self.checkBoxUncheckedDis.setEnabled(False)
        self.checkBoxUncheckedDis.setMinimumSize(QtCore.QSize(0, 0))
        self.checkBoxUncheckedDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.checkBoxUncheckedDis.setChecked(False)
        self.checkBoxUncheckedDis.setObjectName(_fromUtf8("checkBoxUncheckedDis"))
        self.gridLayout.addWidget(self.checkBoxUncheckedDis, 8, 2, 1, 1)
        self.label_31 = QtGui.QLabel(self.dockWidgetContents)
        self.label_31.setMinimumSize(QtCore.QSize(0, 0))
        self.label_31.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_31.setFont(font)
        self.label_31.setObjectName(_fromUtf8("label_31"))
        self.gridLayout.addWidget(self.label_31, 10, 0, 1, 1)
        self.commandLinkButton = QtGui.QCommandLinkButton(self.dockWidgetContents)
        self.commandLinkButton.setMinimumSize(QtCore.QSize(0, 0))
        self.commandLinkButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.commandLinkButton.setObjectName(_fromUtf8("commandLinkButton"))
        self.gridLayout.addWidget(self.commandLinkButton, 10, 1, 1, 1)
        self.commandLinkButtonDIs = QtGui.QCommandLinkButton(self.dockWidgetContents)
        self.commandLinkButtonDIs.setEnabled(False)
        self.commandLinkButtonDIs.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.commandLinkButtonDIs.setObjectName(_fromUtf8("commandLinkButtonDIs"))
        self.gridLayout.addWidget(self.commandLinkButtonDIs, 10, 2, 1, 1)
        self.label_32 = QtGui.QLabel(self.dockWidgetContents)
        self.label_32.setMinimumSize(QtCore.QSize(0, 0))
        self.label_32.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_32.setFont(font)
        self.label_32.setObjectName(_fromUtf8("label_32"))
        self.gridLayout.addWidget(self.label_32, 11, 0, 1, 1)
        self.buttonBox = QtGui.QDialogButtonBox(self.dockWidgetContents)
        self.buttonBox.setMinimumSize(QtCore.QSize(0, 0))
        self.buttonBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.gridLayout.addWidget(self.buttonBox, 11, 1, 1, 1)
        self.buttonBoxDis = QtGui.QDialogButtonBox(self.dockWidgetContents)
        self.buttonBoxDis.setEnabled(False)
        self.buttonBoxDis.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBoxDis.setObjectName(_fromUtf8("buttonBoxDis"))
        self.gridLayout.addWidget(self.buttonBoxDis, 11, 2, 1, 1)
        spacerItem = QtGui.QSpacerItem(20, 4, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 12, 0, 1, 1)
        self.label_36 = QtGui.QLabel(self.dockWidgetContents)
        self.label_36.setAlignment(QtCore.Qt.AlignCenter)
        self.label_36.setObjectName(_fromUtf8("label_36"))
        self.gridLayout.addWidget(self.label_36, 13, 0, 1, 3)
        self.label = QtGui.QLabel(self.dockWidgetContents)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout.addWidget(self.label, 9, 0, 1, 1)
        self.checkBoxTristate = QtGui.QCheckBox(self.dockWidgetContents)
        self.checkBoxTristate.setChecked(False)
        self.checkBoxTristate.setTristate(True)
        self.checkBoxTristate.setObjectName(_fromUtf8("checkBoxTristate"))
        self.gridLayout.addWidget(self.checkBoxTristate, 9, 1, 1, 1)
        self.checkBoxTristateDis = QtGui.QCheckBox(self.dockWidgetContents)
        self.checkBoxTristateDis.setEnabled(False)
        self.checkBoxTristateDis.setChecked(False)
        self.checkBoxTristateDis.setTristate(True)
        self.checkBoxTristateDis.setObjectName(_fromUtf8("checkBoxTristateDis"))
        self.gridLayout.addWidget(self.checkBoxTristateDis, 9, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QObject.connect(self.radioButtonChecked, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.radioButtonCheckedDis.setChecked)
        QtCore.QObject.connect(self.radioButtonUnchecked, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.radioButtonUncheckedDis.setChecked)
        QtCore.QObject.connect(self.checkBoxChecked, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.checkBoxCheckedDis.setChecked)
        QtCore.QObject.connect(self.checkBoxEnabled, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.checkBoxUncheckedDis.setChecked)
        QtCore.QObject.connect(self.checkBoxTristate, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.checkBoxTristateDis.setChecked)
        QtCore.QObject.connect(self.commandLinkButton, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.commandLinkButtonDIs.setChecked)
        QtCore.QObject.connect(self.toolButton, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.toolButtonDis.setChecked)
        QtCore.QObject.connect(self.pushButtonChecked, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.pushButtonCheckedDis.setChecked)
        QtCore.QObject.connect(self.pushButtonUnchecked, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.pushButtonUncheckedDis.setChecked)
        QtCore.QObject.connect(self.pushButton, QtCore.SIGNAL(_fromUtf8("clicked(bool)")), self.pushButtonDis.click)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(_translate("DockWidget", "Buttons", None))
        self.label_72.setText(_translate("DockWidget", "Enabled", None))
        self.label_73.setText(_translate("DockWidget", "Disabled", None))
        self.label_26.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_26.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_26.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_26.setText(_translate("DockWidget", "PushButton", None))
        self.pushButton.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.pushButton.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.pushButton.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.pushButton.setText(_translate("DockWidget", "OK", None))
        self.pushButtonDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.pushButtonDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.pushButtonDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.pushButtonDis.setText(_translate("DockWidget", "OK", None))
        self.label_74.setText(_translate("DockWidget", "PushButton", None))
        self.pushButtonChecked.setText(_translate("DockWidget", "Checked", None))
        self.pushButtonCheckedDis.setText(_translate("DockWidget", "Checked", None))
        self.label_76.setText(_translate("DockWidget", "PushButton", None))
        self.pushButtonUnchecked.setText(_translate("DockWidget", "Unchecked", None))
        self.pushButtonUncheckedDis.setText(_translate("DockWidget", "Unchecked", None))
        self.label_33.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_33.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_33.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_33.setText(_translate("DockWidget", "ToolButton", None))
        self.toolButton.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.toolButton.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.toolButton.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.toolButton.setText(_translate("DockWidget", "Tool", None))
        self.toolButtonDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.toolButtonDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.toolButtonDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.toolButtonDis.setText(_translate("DockWidget", "Tool", None))
        self.label_75.setText(_translate("DockWidget", "RadioButton", None))
        self.radioButtonChecked.setText(_translate("DockWidget", "Checked", None))
        self.radioButtonCheckedDis.setText(_translate("DockWidget", "Checked", None))
        self.label_29.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_29.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_29.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_29.setText(_translate("DockWidget", "RadioButton", None))
        self.radioButtonUnchecked.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.radioButtonUnchecked.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.radioButtonUnchecked.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.radioButtonUnchecked.setText(_translate("DockWidget", "Unchecked", None))
        self.radioButtonUncheckedDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.radioButtonUncheckedDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.radioButtonUncheckedDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.radioButtonUncheckedDis.setText(_translate("DockWidget", "Unchecked", None))
        self.label_53.setText(_translate("DockWidget", "CheckBox", None))
        self.checkBoxChecked.setText(_translate("DockWidget", "Checked", None))
        self.checkBoxCheckedDis.setText(_translate("DockWidget", "Checked", None))
        self.label_30.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_30.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_30.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_30.setText(_translate("DockWidget", "CheckBox", None))
        self.checkBoxEnabled.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.checkBoxEnabled.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.checkBoxEnabled.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.checkBoxEnabled.setText(_translate("DockWidget", "Unchecked", None))
        self.checkBoxUncheckedDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.checkBoxUncheckedDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.checkBoxUncheckedDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.checkBoxUncheckedDis.setText(_translate("DockWidget", "Unchecked", None))
        self.label_31.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_31.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_31.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_31.setText(_translate("DockWidget", "CommandLinkButton", None))
        self.commandLinkButton.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.commandLinkButton.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.commandLinkButton.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.commandLinkButton.setText(_translate("DockWidget", "Command", None))
        self.commandLinkButtonDIs.setText(_translate("DockWidget", "Command", None))
        self.label_32.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_32.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_32.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_32.setText(_translate("DockWidget", "ButtonBox", None))
        self.buttonBox.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.buttonBox.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.buttonBox.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_36.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_36.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_36.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_36.setText(_translate("DockWidget", "Inside DockWidget", None))
        self.label.setText(_translate("DockWidget", "CheckBox", None))
        self.checkBoxTristate.setText(_translate("DockWidget", "Tristate", None))
        self.checkBoxTristateDis.setText(_translate("DockWidget", "Tristate", None))




#!python
# -*- coding: utf-8 -*-

"""Example of qdarkstyle use for Python and Qt applications.

This module a main window with every item that could be created with
Qt Design (common ones) in the basic states (enabled/disabled), and
(checked/unchecked) for those who has this attribute.

Requirements:

    - Python 2 or Python 3
    - PyQt4 or PyQt5 or PySide or PySide2
    - QtPy or PyQtGraph (if choosen)

To run this example using PyQt4, simple do

.. code-block:: python

    python example.py

or

.. code-block:: python

    python example.py  --qt_from=pyqt

Other options for qt_from are: pyqt5, pyside, qtpy and pyqtgraph.

You also can run the example without dark theme (no_dark), to check for
problems.

.. code-block:: python

    python example.py  --qt_from=pyqt --no_dark

.. note.. :: qdarkstyle does not have to be installed to run the example.

"""

import logging
import sys
import argparse
import os

# make the example runnable without the need to install
from os.path import abspath, dirname
sys.path.insert(0, abspath(dirname(abspath(__file__)) + '/..'))

# must be in this place, after setting path, to not need to install
import qdarkstyle
from qdarkstyle import QT_BINDING, QT_ABSTRACTION


def main():
    """Execute QDarkStyle example."""
    parser = argparse.ArgumentParser(description=__doc__,
                                     formatter_class=argparse.RawDescriptionHelpFormatter)
    parser.add_argument('--qt_from', default='qtpy',
                        choices=['pyqt', 'pyqt5', 'pyside','pyside2', 'qtpy', 'pyqtgraph'],
                        help="Choose which wrapper/framework is to be used to run the example.", type=str)
    parser.add_argument('--no_dark', action='store_true',
                        help="Exihibts the original  window (without qdarkstyle).")
    parser.add_argument('--test', action='store_true',
                        help="Auto close window after 2s.")
    parser.add_argument('--reset', action='store_true',
                        help="Reset GUI settings (position, size).")
    # parsing arguments from command line
    args = parser.parse_args()

    # set log for debug
    logging.basicConfig(level=logging.DEBUG)

    # to avoid problems when testing without screen
    if args.test:
        os.environ['QT_QPA_PLATFORM']='offscreen'

    if args.qt_from == 'pyside':
        # using PySide wrapper
        from PySide.QtGui import QApplication, QMainWindow, QDockWidget
        from PySide.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # import examples UI according to wrapper
        from ui.mw_menus_pyside_ui import Ui_MainWindow as ui_main

        from ui.dw_buttons_pyside_ui import Ui_DockWidget as ui_buttons
        from ui.dw_displays_pyside_ui import Ui_DockWidget as ui_displays
        from ui.dw_inputs_fields_pyside_ui import Ui_DockWidget as ui_inputs_fields
        from ui.dw_inputs_no_fields_pyside_ui import Ui_DockWidget as ui_inputs_no_fields

        from ui.dw_widgets_pyside_ui import Ui_DockWidget as ui_widgets
        from ui.dw_views_pyside_ui import Ui_DockWidget as ui_views
        from ui.dw_containers_tabs_pyside_ui import Ui_DockWidget as ui_containers_tabs
        from ui.dw_containers_no_tabs_pyside_ui import Ui_DockWidget as ui_containers_no_tabs
        # getting style
        style = qdarkstyle.load_stylesheet_pyside()

    elif args.qt_from == 'pyqt':
        # using PyQt4 wrapper
        from PyQt4.QtGui import QApplication, QMainWindow, QDockWidget
        from PyQt4.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # import examples UI according to wrapper
        from ui.mw_menus_pyqt_ui import Ui_MainWindow as ui_main

        from ui.dw_buttons_pyqt_ui import Ui_DockWidget as ui_buttons
        from ui.dw_displays_pyqt_ui import Ui_DockWidget as ui_displays
        from ui.dw_inputs_fields_pyqt_ui import Ui_DockWidget as ui_inputs_fields
        from ui.dw_inputs_no_fields_pyqt_ui import Ui_DockWidget as ui_inputs_no_fields

        from ui.dw_widgets_pyqt_ui import Ui_DockWidget as ui_widgets
        from ui.dw_views_pyqt_ui import Ui_DockWidget as ui_views
        from ui.dw_containers_tabs_pyqt_ui import Ui_DockWidget as ui_containers_tabs
        from ui.dw_containers_no_tabs_pyqt_ui import Ui_DockWidget as ui_containers_no_tabs
        # getting style
        style = qdarkstyle.load_stylesheet_pyqt()

    elif args.qt_from == 'pyqt5':
        # using PyQt5 wrapper
        from PyQt5.QtWidgets import QApplication, QMainWindow, QDockWidget
        from PyQt5.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # import examples UI according to wrapper
        from ui.mw_menus_pyqt5_ui import Ui_MainWindow as ui_main

        from ui.dw_buttons_pyqt5_ui import Ui_DockWidget as ui_buttons
        from ui.dw_displays_pyqt5_ui import Ui_DockWidget as ui_displays
        from ui.dw_inputs_fields_pyqt5_ui import Ui_DockWidget as ui_inputs_fields
        from ui.dw_inputs_no_fields_pyqt5_ui import Ui_DockWidget as ui_inputs_no_fields

        from ui.dw_widgets_pyqt5_ui import Ui_DockWidget as ui_widgets
        from ui.dw_views_pyqt5_ui import Ui_DockWidget as ui_views
        from ui.dw_containers_tabs_pyqt5_ui import Ui_DockWidget as ui_containers_tabs
        from ui.dw_containers_no_tabs_pyqt5_ui import Ui_DockWidget as ui_containers_no_tabs
        # getting style
        style = qdarkstyle.load_stylesheet_pyqt5()

    elif args.qt_from == 'pyside2':
        # using PyQt5 wrapper
        from PySide2.QtWidgets import QApplication, QMainWindow, QDockWidget
        from PySide2.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # import examples UI according to wrapper
        from ui.mw_menus_pyside2_ui import Ui_MainWindow as ui_main

        from ui.dw_buttons_pyside2_ui import Ui_DockWidget as ui_buttons
        from ui.dw_displays_pyside2_ui import Ui_DockWidget as ui_displays
        from ui.dw_inputs_fields_pyside2_ui import Ui_DockWidget as ui_inputs_fields
        from ui.dw_inputs_no_fields_pyside2_ui import Ui_DockWidget as ui_inputs_no_fields

        from ui.dw_widgets_pyside2_ui import Ui_DockWidget as ui_widgets
        from ui.dw_views_pyside2_ui import Ui_DockWidget as ui_views
        from ui.dw_containers_tabs_pyside2_ui import Ui_DockWidget as ui_containers_tabs
        from ui.dw_containers_no_tabs_pyside2_ui import Ui_DockWidget as ui_containers_no_tabs
        # getting style
        style = qdarkstyle.load_stylesheet_pyside2()

    elif args.qt_from == 'qtpy':
        # using QtPy API
        from qtpy.QtWidgets import QApplication, QMainWindow, QDockWidget
        from qtpy.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # import examples UI according to wrapper
        from ui.mw_menus_qtpy_ui import Ui_MainWindow as ui_main

        from ui.dw_buttons_qtpy_ui import Ui_DockWidget as ui_buttons
        from ui.dw_displays_qtpy_ui import Ui_DockWidget as ui_displays
        from ui.dw_inputs_fields_qtpy_ui import Ui_DockWidget as ui_inputs_fields
        from ui.dw_inputs_no_fields_qtpy_ui import Ui_DockWidget as ui_inputs_no_fields

        from ui.dw_widgets_qtpy_ui import Ui_DockWidget as ui_widgets
        from ui.dw_views_qtpy_ui import Ui_DockWidget as ui_views
        from ui.dw_containers_tabs_qtpy_ui import Ui_DockWidget as ui_containers_tabs
        from ui.dw_containers_no_tabs_qtpy_ui import Ui_DockWidget as ui_containers_no_tabs
        # getting style
        style = qdarkstyle.load_stylesheet_from_environment()

    elif args.qt_from == 'pyqtgraph':
        # using PyQtGraph API
        from pyqtgraph.Qt.QtGui import QApplication, QMainWindow, QDockWidget
        from pyqtgraph.Qt.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        #from pyqtgraph.Qt import QtGui, QtCore
        # import examples UI according to wrapper
        from ui.mw_menus_pyqtgraph_ui import Ui_MainWindow as ui_main
        from ui.dw_buttons_pyqtgraph_ui import Ui_DockWidget as ui_buttons
        from ui.dw_displays_pyqtgraph_ui import Ui_DockWidget as ui_displays
        from ui.dw_inputs_fields_pyqtgraph_ui import Ui_DockWidget as ui_inputs_fields
        from ui.dw_inputs_no_fields_pyqtgraph_ui import Ui_DockWidget as ui_inputs_no_fields
        from ui.dw_widgets_pyqtgraph_ui import Ui_DockWidget as ui_widgets
        from ui.dw_views_pyqtgraph_ui import Ui_DockWidget as ui_views
        from ui.dw_containers_tabs_pyqtgraph_ui import Ui_DockWidget as ui_containers_tabs
        from ui.dw_containers_no_tabs_pyqtgraph_ui import Ui_DockWidget as ui_containers_no_tabs
        # getting style
        style = qdarkstyle.load_stylesheet_from_environment(is_pyqtgraph=True)

    if args.no_dark:
        style = ''

    def write_settings(window):
        """Get window settings and write it into a file."""
        settings = QSettings('QDarkStyle', 'QDarkStyle Example')
        settings.setValue('pos', window.pos())
        settings.setValue('size', window.size())
        settings.setValue('state', window.saveState())

    def read_settings(window, reset=False):
        """Read and set window settings from a file."""
        settings = QSettings('QDarkStyle', 'QDarkStyle Example')
        if args.qt_from == 'pyside' or args.qt_from == 'pyside2':
            pos = settings.value('pos', window.pos())
            size = settings.value('size', window.size())
            state = settings.value('state', window.saveState())
        else:
            pos = settings.value('pos', window.pos(), type='QPoint')
            size = settings.value('size', window.size(), type='QSize')
            state = settings.value('state', window.saveState(), type='QByteArray')

        if not reset:
            window.restoreState(state)
            window.resize(size)
            window.move(pos)




    # create the application
    app = QApplication(sys.argv)
    app.setOrganizationName('QDarkStyle')
    app.setApplicationName('QDarkStyle Example')

    # setup stylesheet
    app.setStyleSheet(style)

    # create main window
    window = QMainWindow()
    window.setObjectName('mainwindow')
    ui = ui_main()
    ui.setupUi(window)
    window.setWindowTitle("QDarkStyle v." + qdarkstyle.__version__)

    # create docks for buttons
    dw_buttons = QDockWidget()
    dw_buttons.setObjectName('buttons')
    ui_buttons = ui_buttons()
    ui_buttons.setupUi(dw_buttons)
    window.addDockWidget(Qt.RightDockWidgetArea, dw_buttons)

    # create docks for buttons
    dw_displays = QDockWidget()
    dw_displays.setObjectName('displays')
    ui_displays = ui_displays()
    ui_displays.setupUi(dw_displays)
    window.addDockWidget(Qt.RightDockWidgetArea, dw_displays)

    # create docks for inputs - no fields
    dw_inputs_no_fields = QDockWidget()
    dw_inputs_no_fields.setObjectName('inputs_no_fields')
    ui_inputs_no_fields = ui_inputs_no_fields()
    ui_inputs_no_fields.setupUi(dw_inputs_no_fields)
    window.addDockWidget(Qt.RightDockWidgetArea, dw_inputs_no_fields)

    # create docks for inputs - fields
    dw_inputs_fields = QDockWidget()
    dw_inputs_fields.setObjectName('_fields')
    ui_inputs_fields = ui_inputs_fields()
    ui_inputs_fields.setupUi(dw_inputs_fields)
    window.addDockWidget(Qt.RightDockWidgetArea, dw_inputs_fields)

    # create docks for widgets
    dw_widgets = QDockWidget()
    dw_widgets.setObjectName('widgets')
    ui_widgets = ui_widgets()
    ui_widgets.setupUi(dw_widgets)
    window.addDockWidget(Qt.LeftDockWidgetArea, dw_widgets)

    # create docks for views
    dw_views = QDockWidget()
    dw_views.setObjectName('views')
    ui_views = ui_views()
    ui_views.setupUi(dw_views)
    window.addDockWidget(Qt.LeftDockWidgetArea, dw_views)

    # create docks for containers - no tabs
    dw_containers_no_tabs = QDockWidget()
    dw_containers_no_tabs.setObjectName('containers_no_tabs')
    ui_containers_no_tabs = ui_containers_no_tabs()
    ui_containers_no_tabs.setupUi(dw_containers_no_tabs)
    window.addDockWidget(Qt.LeftDockWidgetArea, dw_containers_no_tabs)

    # create docks for containters - tabs
    dw_containers_tabs = QDockWidget()
    dw_containers_tabs.setObjectName('containers')
    ui_containers_tabs = ui_containers_tabs()
    ui_containers_tabs.setupUi(dw_containers_tabs)
    window.addDockWidget(Qt.LeftDockWidgetArea, dw_containers_tabs)

    # tabify right docks
    window.tabifyDockWidget(dw_buttons, dw_displays)
    window.tabifyDockWidget(dw_displays, dw_inputs_fields)
    window.tabifyDockWidget(dw_inputs_fields, dw_inputs_no_fields)

    # tabify right docks
    window.tabifyDockWidget(dw_containers_no_tabs, dw_containers_tabs)
    window.tabifyDockWidget(dw_containers_tabs, dw_widgets)
    window.tabifyDockWidget(dw_widgets, dw_views)

    # auto quit after 2s when testing on travis-ci
    if args.test:
        QTimer.singleShot(2000, app.exit)

    # run
    qdarkstyle.information()
    read_settings(window, args.reset)
    window.showMaximized()
    app.exec_()
    write_settings(window)



if __name__ == "__main__":
    sys.exit(main())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_widgets.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from pyqtgraph.Qt import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName(_fromUtf8("DockWidget"))
        DockWidget.resize(269, 306)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label_81 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_81.setFont(font)
        self.label_81.setObjectName(_fromUtf8("label_81"))
        self.gridLayout.addWidget(self.label_81, 0, 1, 1, 1)
        self.label_82 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_82.setFont(font)
        self.label_82.setObjectName(_fromUtf8("label_82"))
        self.gridLayout.addWidget(self.label_82, 0, 2, 1, 1)
        self.label_56 = QtGui.QLabel(self.dockWidgetContents)
        self.label_56.setMinimumSize(QtCore.QSize(0, 0))
        self.label_56.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_56.setFont(font)
        self.label_56.setObjectName(_fromUtf8("label_56"))
        self.gridLayout.addWidget(self.label_56, 1, 0, 1, 1)
        self.listWidget = QtGui.QListWidget(self.dockWidgetContents)
        self.listWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.listWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.listWidget.setObjectName(_fromUtf8("listWidget"))
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        self.gridLayout.addWidget(self.listWidget, 1, 1, 1, 1)
        self.listWidgetDis = QtGui.QListWidget(self.dockWidgetContents)
        self.listWidgetDis.setEnabled(False)
        self.listWidgetDis.setObjectName(_fromUtf8("listWidgetDis"))
        item = QtGui.QListWidgetItem()
        self.listWidgetDis.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidgetDis.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidgetDis.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidgetDis.addItem(item)
        self.gridLayout.addWidget(self.listWidgetDis, 1, 2, 1, 1)
        self.label_57 = QtGui.QLabel(self.dockWidgetContents)
        self.label_57.setMinimumSize(QtCore.QSize(0, 0))
        self.label_57.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_57.setFont(font)
        self.label_57.setObjectName(_fromUtf8("label_57"))
        self.gridLayout.addWidget(self.label_57, 2, 0, 1, 1)
        self.treeWidget = QtGui.QTreeWidget(self.dockWidgetContents)
        self.treeWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.treeWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.treeWidget.setObjectName(_fromUtf8("treeWidget"))
        item_0 = QtGui.QTreeWidgetItem(self.treeWidget)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        item_2 = QtGui.QTreeWidgetItem(item_1)
        item_0 = QtGui.QTreeWidgetItem(self.treeWidget)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        self.gridLayout.addWidget(self.treeWidget, 2, 1, 1, 1)
        self.treeWidgetDis = QtGui.QTreeWidget(self.dockWidgetContents)
        self.treeWidgetDis.setEnabled(False)
        self.treeWidgetDis.setObjectName(_fromUtf8("treeWidgetDis"))
        item_0 = QtGui.QTreeWidgetItem(self.treeWidgetDis)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        item_2 = QtGui.QTreeWidgetItem(item_1)
        item_0 = QtGui.QTreeWidgetItem(self.treeWidgetDis)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        self.gridLayout.addWidget(self.treeWidgetDis, 2, 2, 1, 1)
        self.label_58 = QtGui.QLabel(self.dockWidgetContents)
        self.label_58.setMinimumSize(QtCore.QSize(0, 0))
        self.label_58.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_58.setFont(font)
        self.label_58.setObjectName(_fromUtf8("label_58"))
        self.gridLayout.addWidget(self.label_58, 3, 0, 1, 1)
        self.tableWidget = QtGui.QTableWidget(self.dockWidgetContents)
        self.tableWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.tableWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.tableWidget.setObjectName(_fromUtf8("tableWidget"))
        self.tableWidget.setColumnCount(2)
        self.tableWidget.setRowCount(3)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(0, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(0, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(1, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(1, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(2, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(2, 1, item)
        self.gridLayout.addWidget(self.tableWidget, 3, 1, 1, 1)
        self.tableWidgetDis = QtGui.QTableWidget(self.dockWidgetContents)
        self.tableWidgetDis.setEnabled(False)
        self.tableWidgetDis.setObjectName(_fromUtf8("tableWidgetDis"))
        self.tableWidgetDis.setColumnCount(2)
        self.tableWidgetDis.setRowCount(3)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setVerticalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setVerticalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setVerticalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(0, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(0, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(1, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(1, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(2, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(2, 1, item)
        self.gridLayout.addWidget(self.tableWidgetDis, 3, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(_translate("DockWidget", "Widgets", None))
        self.label_81.setText(_translate("DockWidget", "Enabled", None))
        self.label_82.setText(_translate("DockWidget", "Disabled", None))
        self.label_56.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_56.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_56.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_56.setText(_translate("DockWidget", "ListWidget", None))
        self.listWidget.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.listWidget.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.listWidget.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        __sortingEnabled = self.listWidget.isSortingEnabled()
        self.listWidget.setSortingEnabled(False)
        item = self.listWidget.item(0)
        item.setText(_translate("DockWidget", "New Item", None))
        item = self.listWidget.item(1)
        item.setText(_translate("DockWidget", "New Item", None))
        item = self.listWidget.item(2)
        item.setText(_translate("DockWidget", "New Item", None))
        item = self.listWidget.item(3)
        item.setText(_translate("DockWidget", "New Item", None))
        self.listWidget.setSortingEnabled(__sortingEnabled)
        __sortingEnabled = self.listWidgetDis.isSortingEnabled()
        self.listWidgetDis.setSortingEnabled(False)
        item = self.listWidgetDis.item(0)
        item.setText(_translate("DockWidget", "New Item", None))
        item = self.listWidgetDis.item(1)
        item.setText(_translate("DockWidget", "New Item", None))
        item = self.listWidgetDis.item(2)
        item.setText(_translate("DockWidget", "New Item", None))
        item = self.listWidgetDis.item(3)
        item.setText(_translate("DockWidget", "New Item", None))
        self.listWidgetDis.setSortingEnabled(__sortingEnabled)
        self.label_57.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_57.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_57.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_57.setText(_translate("DockWidget", "TreeWidget", None))
        self.treeWidget.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.treeWidget.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.treeWidget.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.treeWidget.setSortingEnabled(True)
        self.treeWidget.headerItem().setText(0, _translate("DockWidget", "New Column", None))
        self.treeWidget.headerItem().setText(1, _translate("DockWidget", "New Column", None))
        __sortingEnabled = self.treeWidget.isSortingEnabled()
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.topLevelItem(0).setText(0, _translate("DockWidget", "New Item", None))
        self.treeWidget.topLevelItem(0).child(0).setText(0, _translate("DockWidget", "New Subitem", None))
        self.treeWidget.topLevelItem(0).child(0).setText(1, _translate("DockWidget", "Test", None))
        self.treeWidget.topLevelItem(0).child(0).child(0).setText(0, _translate("DockWidget", "New Subitem", None))
        self.treeWidget.topLevelItem(1).setText(0, _translate("DockWidget", "New Item", None))
        self.treeWidget.topLevelItem(1).child(0).setText(0, _translate("DockWidget", "New Subitem", None))
        self.treeWidget.setSortingEnabled(__sortingEnabled)
        self.treeWidgetDis.setSortingEnabled(True)
        self.treeWidgetDis.headerItem().setText(0, _translate("DockWidget", "New Column", None))
        self.treeWidgetDis.headerItem().setText(1, _translate("DockWidget", "New Column", None))
        __sortingEnabled = self.treeWidgetDis.isSortingEnabled()
        self.treeWidgetDis.setSortingEnabled(False)
        self.treeWidgetDis.topLevelItem(0).setText(0, _translate("DockWidget", "New Item", None))
        self.treeWidgetDis.topLevelItem(0).child(0).setText(0, _translate("DockWidget", "New Subitem", None))
        self.treeWidgetDis.topLevelItem(0).child(0).setText(1, _translate("DockWidget", "Test", None))
        self.treeWidgetDis.topLevelItem(0).child(0).child(0).setText(0, _translate("DockWidget", "New Subitem", None))
        self.treeWidgetDis.topLevelItem(1).setText(0, _translate("DockWidget", "New Item", None))
        self.treeWidgetDis.topLevelItem(1).child(0).setText(0, _translate("DockWidget", "New Subitem", None))
        self.treeWidgetDis.setSortingEnabled(__sortingEnabled)
        self.label_58.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_58.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_58.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_58.setText(_translate("DockWidget", "TableWidget", None))
        self.tableWidget.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.tableWidget.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.tableWidget.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        item = self.tableWidget.verticalHeaderItem(0)
        item.setText(_translate("DockWidget", "New Row", None))
        item = self.tableWidget.verticalHeaderItem(1)
        item.setText(_translate("DockWidget", "New Row", None))
        item = self.tableWidget.verticalHeaderItem(2)
        item.setText(_translate("DockWidget", "New Row", None))
        item = self.tableWidget.horizontalHeaderItem(0)
        item.setText(_translate("DockWidget", "New Column", None))
        item = self.tableWidget.horizontalHeaderItem(1)
        item.setText(_translate("DockWidget", "New Column", None))
        __sortingEnabled = self.tableWidget.isSortingEnabled()
        self.tableWidget.setSortingEnabled(False)
        item = self.tableWidget.item(0, 0)
        item.setText(_translate("DockWidget", "1.23", None))
        item = self.tableWidget.item(0, 1)
        item.setText(_translate("DockWidget", "Hello", None))
        item = self.tableWidget.item(1, 0)
        item.setText(_translate("DockWidget", "1,45", None))
        item = self.tableWidget.item(1, 1)
        item.setText(_translate("DockWidget", "Olá", None))
        item = self.tableWidget.item(2, 0)
        item.setText(_translate("DockWidget", "12/12/2012", None))
        item = self.tableWidget.item(2, 1)
        item.setText(_translate("DockWidget", "Oui", None))
        self.tableWidget.setSortingEnabled(__sortingEnabled)
        item = self.tableWidgetDis.verticalHeaderItem(0)
        item.setText(_translate("DockWidget", "New Row", None))
        item = self.tableWidgetDis.verticalHeaderItem(1)
        item.setText(_translate("DockWidget", "New Row", None))
        item = self.tableWidgetDis.verticalHeaderItem(2)
        item.setText(_translate("DockWidget", "New Row", None))
        item = self.tableWidgetDis.horizontalHeaderItem(0)
        item.setText(_translate("DockWidget", "New Column", None))
        item = self.tableWidgetDis.horizontalHeaderItem(1)
        item.setText(_translate("DockWidget", "New Column", None))
        __sortingEnabled = self.tableWidgetDis.isSortingEnabled()
        self.tableWidgetDis.setSortingEnabled(False)
        item = self.tableWidgetDis.item(0, 0)
        item.setText(_translate("DockWidget", "1.23", None))
        item = self.tableWidgetDis.item(0, 1)
        item.setText(_translate("DockWidget", "Hello", None))
        item = self.tableWidgetDis.item(1, 0)
        item.setText(_translate("DockWidget", "1,45", None))
        item = self.tableWidgetDis.item(1, 1)
        item.setText(_translate("DockWidget", "Olá", None))
        item = self.tableWidgetDis.item(2, 0)
        item.setText(_translate("DockWidget", "12/12/2012", None))
        item = self.tableWidgetDis.item(2, 1)
        item.setText(_translate("DockWidget", "Oui", None))
        self.tableWidgetDis.setSortingEnabled(__sortingEnabled)




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_inputs_no_fields.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName(_fromUtf8("DockWidget"))
        DockWidget.resize(402, 405)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.dial = QtGui.QDial(self.dockWidgetContents)
        self.dial.setMinimumSize(QtCore.QSize(0, 0))
        self.dial.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dial.setProperty("value", 50)
        self.dial.setObjectName(_fromUtf8("dial"))
        self.gridLayout.addWidget(self.dial, 2, 1, 1, 1)
        self.label_25 = QtGui.QLabel(self.dockWidgetContents)
        self.label_25.setMinimumSize(QtCore.QSize(0, 0))
        self.label_25.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_25.setFont(font)
        self.label_25.setObjectName(_fromUtf8("label_25"))
        self.gridLayout.addWidget(self.label_25, 7, 0, 1, 1)
        self.horizontalScrollBarDis = QtGui.QScrollBar(self.dockWidgetContents)
        self.horizontalScrollBarDis.setEnabled(False)
        self.horizontalScrollBarDis.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalScrollBarDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalScrollBarDis.setProperty("value", 50)
        self.horizontalScrollBarDis.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalScrollBarDis.setObjectName(_fromUtf8("horizontalScrollBarDis"))
        self.gridLayout.addWidget(self.horizontalScrollBarDis, 3, 2, 1, 1)
        self.verticalSlider = QtGui.QSlider(self.dockWidgetContents)
        self.verticalSlider.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalSlider.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalSlider.setProperty("value", 50)
        self.verticalSlider.setOrientation(QtCore.Qt.Vertical)
        self.verticalSlider.setObjectName(_fromUtf8("verticalSlider"))
        self.gridLayout.addWidget(self.verticalSlider, 7, 1, 1, 1)
        self.label_24 = QtGui.QLabel(self.dockWidgetContents)
        self.label_24.setMinimumSize(QtCore.QSize(0, 0))
        self.label_24.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_24.setFont(font)
        self.label_24.setObjectName(_fromUtf8("label_24"))
        self.gridLayout.addWidget(self.label_24, 4, 0, 1, 1)
        self.horizontalSlider = QtGui.QSlider(self.dockWidgetContents)
        self.horizontalSlider.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalSlider.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalSlider.setProperty("value", 50)
        self.horizontalSlider.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider.setObjectName(_fromUtf8("horizontalSlider"))
        self.gridLayout.addWidget(self.horizontalSlider, 4, 1, 2, 1)
        self.horizontalSliderDis = QtGui.QSlider(self.dockWidgetContents)
        self.horizontalSliderDis.setEnabled(False)
        self.horizontalSliderDis.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalSliderDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalSliderDis.setProperty("value", 50)
        self.horizontalSliderDis.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSliderDis.setObjectName(_fromUtf8("horizontalSliderDis"))
        self.gridLayout.addWidget(self.horizontalSliderDis, 4, 2, 1, 1)
        self.label_23 = QtGui.QLabel(self.dockWidgetContents)
        self.label_23.setMinimumSize(QtCore.QSize(0, 0))
        self.label_23.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_23.setFont(font)
        self.label_23.setObjectName(_fromUtf8("label_23"))
        self.gridLayout.addWidget(self.label_23, 6, 0, 1, 1)
        self.label_2 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 0, 2, 1, 1)
        self.verticalScrollBarDis = QtGui.QScrollBar(self.dockWidgetContents)
        self.verticalScrollBarDis.setEnabled(False)
        self.verticalScrollBarDis.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalScrollBarDis.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalScrollBarDis.setProperty("value", 50)
        self.verticalScrollBarDis.setOrientation(QtCore.Qt.Vertical)
        self.verticalScrollBarDis.setObjectName(_fromUtf8("verticalScrollBarDis"))
        self.gridLayout.addWidget(self.verticalScrollBarDis, 5, 2, 2, 1)
        self.label_21 = QtGui.QLabel(self.dockWidgetContents)
        self.label_21.setMinimumSize(QtCore.QSize(0, 0))
        self.label_21.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_21.setFont(font)
        self.label_21.setObjectName(_fromUtf8("label_21"))
        self.gridLayout.addWidget(self.label_21, 2, 0, 1, 1)
        spacerItem = QtGui.QSpacerItem(20, 0, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 8, 0, 1, 1)
        self.verticalScrollBar = QtGui.QScrollBar(self.dockWidgetContents)
        self.verticalScrollBar.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalScrollBar.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalScrollBar.setProperty("value", 50)
        self.verticalScrollBar.setOrientation(QtCore.Qt.Vertical)
        self.verticalScrollBar.setObjectName(_fromUtf8("verticalScrollBar"))
        self.gridLayout.addWidget(self.verticalScrollBar, 6, 1, 1, 1)
        self.comboBoxDis = QtGui.QComboBox(self.dockWidgetContents)
        self.comboBoxDis.setEnabled(False)
        self.comboBoxDis.setMinimumSize(QtCore.QSize(0, 0))
        self.comboBoxDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.comboBoxDis.setObjectName(_fromUtf8("comboBoxDis"))
        self.comboBoxDis.addItem(_fromUtf8(""))
        self.comboBoxDis.addItem(_fromUtf8(""))
        self.comboBoxDis.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.comboBoxDis, 1, 2, 1, 1)
        self.horizontalScrollBar = QtGui.QScrollBar(self.dockWidgetContents)
        self.horizontalScrollBar.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalScrollBar.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalScrollBar.setProperty("value", 50)
        self.horizontalScrollBar.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalScrollBar.setObjectName(_fromUtf8("horizontalScrollBar"))
        self.gridLayout.addWidget(self.horizontalScrollBar, 3, 1, 1, 1)
        self.comboBox = QtGui.QComboBox(self.dockWidgetContents)
        self.comboBox.setMinimumSize(QtCore.QSize(0, 0))
        self.comboBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.comboBox.setObjectName(_fromUtf8("comboBox"))
        self.comboBox.addItem(_fromUtf8(""))
        self.comboBox.addItem(_fromUtf8(""))
        self.comboBox.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.comboBox, 1, 1, 1, 1)
        self.label_22 = QtGui.QLabel(self.dockWidgetContents)
        self.label_22.setMinimumSize(QtCore.QSize(0, 0))
        self.label_22.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_22.setFont(font)
        self.label_22.setObjectName(_fromUtf8("label_22"))
        self.gridLayout.addWidget(self.label_22, 3, 0, 1, 1)
        self.label = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout.addWidget(self.label, 0, 1, 1, 1)
        self.label_50 = QtGui.QLabel(self.dockWidgetContents)
        self.label_50.setAlignment(QtCore.Qt.AlignCenter)
        self.label_50.setObjectName(_fromUtf8("label_50"))
        self.gridLayout.addWidget(self.label_50, 9, 0, 1, 3)
        self.label_11 = QtGui.QLabel(self.dockWidgetContents)
        self.label_11.setMinimumSize(QtCore.QSize(0, 0))
        self.label_11.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_11.setFont(font)
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.gridLayout.addWidget(self.label_11, 1, 0, 1, 1)
        self.dialDis = QtGui.QDial(self.dockWidgetContents)
        self.dialDis.setEnabled(False)
        self.dialDis.setMinimumSize(QtCore.QSize(0, 0))
        self.dialDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dialDis.setProperty("value", 50)
        self.dialDis.setObjectName(_fromUtf8("dialDis"))
        self.gridLayout.addWidget(self.dialDis, 2, 2, 1, 1)
        self.verticalSliderDis = QtGui.QSlider(self.dockWidgetContents)
        self.verticalSliderDis.setEnabled(False)
        self.verticalSliderDis.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalSliderDis.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalSliderDis.setProperty("value", 50)
        self.verticalSliderDis.setOrientation(QtCore.Qt.Vertical)
        self.verticalSliderDis.setObjectName(_fromUtf8("verticalSliderDis"))
        self.gridLayout.addWidget(self.verticalSliderDis, 7, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QObject.connect(self.dial, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.dialDis.setValue)
        QtCore.QObject.connect(self.horizontalScrollBar, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.horizontalScrollBarDis.setValue)
        QtCore.QObject.connect(self.horizontalSlider, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.horizontalSliderDis.setValue)
        QtCore.QObject.connect(self.verticalScrollBar, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.verticalScrollBarDis.setValue)
        QtCore.QObject.connect(self.verticalSlider, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.verticalSliderDis.setValue)
        QtCore.QObject.connect(self.comboBox, QtCore.SIGNAL(_fromUtf8("currentIndexChanged(int)")), self.comboBoxDis.setCurrentIndex)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(_translate("DockWidget", "Inputs - No Fields", None))
        self.dial.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.dial.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.dial.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_25.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_25.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_25.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_25.setText(_translate("DockWidget", "VerticalSlider", None))
        self.horizontalScrollBarDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.horizontalScrollBarDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.horizontalScrollBarDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.verticalSlider.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.verticalSlider.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.verticalSlider.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_24.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_24.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_24.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_24.setText(_translate("DockWidget", "HorizontalSlider", None))
        self.horizontalSlider.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.horizontalSlider.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.horizontalSlider.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.horizontalSliderDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.horizontalSliderDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.horizontalSliderDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_23.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_23.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_23.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_23.setText(_translate("DockWidget", "VerticalScroolBar", None))
        self.label_2.setText(_translate("DockWidget", "Disabled", None))
        self.verticalScrollBarDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.verticalScrollBarDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.verticalScrollBarDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_21.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_21.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_21.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_21.setText(_translate("DockWidget", "Dial", None))
        self.verticalScrollBar.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.verticalScrollBar.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.verticalScrollBar.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.comboBoxDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.comboBoxDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.comboBoxDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.comboBoxDis.setItemText(0, _translate("DockWidget", "ComboBox A", None))
        self.comboBoxDis.setItemText(1, _translate("DockWidget", "ComboBox B", None))
        self.comboBoxDis.setItemText(2, _translate("DockWidget", "ComboBox C", None))
        self.horizontalScrollBar.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.horizontalScrollBar.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.horizontalScrollBar.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.comboBox.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.comboBox.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.comboBox.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.comboBox.setItemText(0, _translate("DockWidget", "ComboBox A", None))
        self.comboBox.setItemText(1, _translate("DockWidget", "ComboBox B", None))
        self.comboBox.setItemText(2, _translate("DockWidget", "ComboBox C", None))
        self.label_22.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_22.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_22.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_22.setText(_translate("DockWidget", "HorizontalScroolBar", None))
        self.label.setText(_translate("DockWidget", "Enabled", None))
        self.label_50.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_50.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_50.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_50.setText(_translate("DockWidget", "Inside DockWidget", None))
        self.label_11.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_11.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_11.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_11.setText(_translate("DockWidget", "ComboBox", None))
        self.dialDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.dialDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.dialDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.verticalSliderDis.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.verticalSliderDis.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.verticalSliderDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""QDarkStyle is a dark stylesheet for Python and Qt applications.

This module provides a function to transparently load the stylesheets
with the correct rc file.

First, start importing our module

.. code-block:: python

    import qdarkstyle

Then you can get stylesheet provided by QDarkStyle for various Qt wrappers
as shown bellow

.. code-block:: python

    # PySide
    dark_stylesheet = qdarkstyle.load_stylesheet_pyside()
    # PySide 2
    dark_stylesheet = qdarkstyle.load_stylesheet_pyside2()
    # PyQt4
    dark_stylesheet = qdarkstyle.load_stylesheet_pyqt()
    # PyQt5
    dark_stylesheet = qdarkstyle.load_stylesheet_pyqt5()

Or from environment variables provided for QtPy or PyQtGraph, see

.. code-block:: python

    # QtPy
    dark_stylesheet = qdarkstyle.load_stylesheet_from_environment()
    # PyQtGraph
    dark_stylesheet = qdarkstyle.load_stylesheet_from_environment(is_pyqtgraph)

Finally, set your QApplication with it

.. code-block:: python

    app.setStyleSheet(dark_stylesheet)

Enjoy!

"""

import logging
import os
import platform
import sys
import warnings
import copy

if sys.version_info >= (3, 4):
    import importlib

__version__ = "2.6.5"


QT_BINDINGS = ['PyQt4', 'PyQt5', 'PySide', 'PySide2']
"""list: values of all Qt bindings to import."""

QT_ABSTRACTIONS = ['qtpy', 'pyqtgraph', 'Qt']
"""list: values of all Qt abstraction layers to import."""

QT4_IMPORT_API = ['QtCore', 'QtGui']
"""list: which subpackage to import for Qt4 API."""

QT5_IMPORT_API = ['QtCore', 'QtGui', 'QtWidgets']
"""list: which subpackage to import for Qt5 API."""

QT_API_VALUES = ['pyqt', 'pyqt5', 'pyside', 'pyside2']
"""list: values for QT_API environment variable used by QtPy."""

QT_LIB_VALUES = ['PyQt', 'PyQt5', 'PySide', 'PySide2']
"""list: values for PYQTGRAPH_QT_LIB environment variable used by PyQtGraph."""

QT_BINDING = 'Not set or nonexistent'
"""str: Qt binding in use."""

QT_ABSTRACTION = 'Not set or nonexistent'
"""str: Qt abstraction layer in use."""


def _logger():
    return logging.getLogger('qdarkstyle')


def _qt_wrapper_import(qt_api):
    """
    Check if Qt API defined can be imported.

    :param qt_api: Qt API string to test import

    :return load function fot given qt_api, otherwise empty string

    """
    qt_wrapper = ''
    loader = ""

    try:
        if qt_api == 'PyQt' or qt_api == 'pyqt':
            import PyQt4
            qt_wrapper = 'PyQt4'
            loader = load_stylesheet_pyqt()
        elif qt_api == 'PyQt5' or qt_api == 'pyqt5':
            import PyQt5
            qt_wrapper = 'PyQt5'
            loader = load_stylesheet_pyqt5()
        elif qt_api == 'PySide' or qt_api == 'pyside':
            import PySide
            qt_wrapper = 'PySide'
            loader = load_stylesheet_pyside()
        elif qt_api == 'PySide2' or qt_api == 'pyside2':
            import PySide2
            qt_wrapper = 'PySide2'
            loader = load_stylesheet_pyside2()
    except ImportError as err:
        _logger().error("Impossible import Qt wrapper.\n %s", str(err))
    else:
        _logger().info("Using Qt wrapper = %s ", qt_wrapper)
        QT_BINDING = qt_wrapper
    finally:
        return loader


def load_stylesheet_from_environment(is_pyqtgraph=False):
    """
    Load the stylesheet from QT_API (or PYQTGRAPH_QT_LIB) environment variable.

    :param is_pyqtgraph: True if it is to be set using PYQTGRAPH_QT_LIB

    :raise KeyError: if QT_API/PYQTGRAPH_QT_LIB does not exist

    :return the stylesheet string
    """
    warnings.warn(
        "load_stylesheet_from_environment() will be deprecated in version 3,"
        "use load_stylesheet()",
        PendingDeprecationWarning
    )
    qt_api = ''
    pyqtgraph_qt_lib = ''

    loader = ""

    # Get values from QT_API
    try:
        qt_api = os.environ['QT_API']
    except KeyError as err:
        # Log this error just if using QT_API
        if not is_pyqtgraph:
            _logger().error("QT_API does not exist, do os.environ['QT_API']= "
                            "and choose one option from %s", QT_API_VALUES)
    else:
        if not is_pyqtgraph:
            if qt_api in QT_API_VALUES:
                QT_ABSTRACTION = "qtpy"
                _logger().info("Found QT_API='%s'", qt_api)
                loader = _qt_wrapper_import(qt_api)
            else:
                # Raise this error because the function need this key/value
                raise KeyError("QT_API=%s is unknown, please use a value "
                               "from %s",
                               (qt_api, QT_API_VALUES))

    # Get values from PYQTGRAPH_QT_LIB
    try:
        pyqtgraph_qt_lib = os.environ['PYQTGRAPH_QT_LIB']
    except KeyError as err:
        # Log this error just if using PYQTGRAPH_QT_LIB
        if is_pyqtgraph:
            _logger().error("PYQTGRAP_QT_API does not exist, do "
                            "os.environ['PYQTGRAPH_QT_LIB']= "
                            "and choose one option from %s",
                            QT_LIB_VALUES)
    else:

        if is_pyqtgraph:
            if pyqtgraph_qt_lib in QT_LIB_VALUES:
                QT_ABSTRACTION = "pyqtgraph"
                _logger().info("Found PYQTGRAPH_QT_LIB='%s'", pyqtgraph_qt_lib)
                loader = _qt_wrapper_import(pyqtgraph_qt_lib)
            else:
                # Raise this error because the function need this key/value
                raise KeyError("PYQTGRAPH_QT_LIB=%s is unknown, please use a "
                               "value from %s", (
                                   pyqtgraph_qt_lib,
                                   QT_LIB_VALUES))

    # Just a warning if both are set but differs each other
    if qt_api and pyqtgraph_qt_lib:
        if qt_api != pyqtgraph_qt_lib.lower():
            _logger().warning("Both QT_API=%s and PYQTGRAPH_QT_LIB=%s are set, "
                              "but with different values, this could cause "
                              "some issues if using them in the same project!",
                              qt_api, pyqtgraph_qt_lib)

    return loader


def load_stylesheet(pyside=True):
    """
    Load the stylesheet. Takes care of importing the rc module.

    :param pyside: True to load the pyside rc file, False to load the PyQt rc file

    :return the stylesheet string
    """
    warnings.warn(
        "load_stylesheet() will not receive pyside parameter in version 3. "
        "Set QtPy environment variable to specify the Qt binding insteady.",
        FutureWarning
    )
    # Smart import of the rc file

    pyside_ver = None

    if pyside:

        # Detect the PySide version available
        try:
            import PySide
        except ImportError: # Compatible with py27
            import PySide2
            pyside_ver = 2
        else:
            pyside_ver = 1

        if pyside_ver == 1:
            import qdarkstyle.pyside_style_rc
        else:
            import qdarkstyle.pyside2_style_rc
    else:
        import qdarkstyle.pyqt_style_rc

    # Load the stylesheet content from resources
    if not pyside:
        from PyQt4.QtCore import QFile, QTextStream
    else:
        if pyside_ver == 1:
            from PySide.QtCore import QFile, QTextStream
        else:
            from PySide2.QtCore import QFile, QTextStream

    f = QFile(":qdarkstyle/style.qss")
    if not f.exists():
        _logger().error("Unable to load stylesheet, file not found in "
                        "resources")
        return ""
    else:
        f.open(QFile.ReadOnly | QFile.Text)
        ts = QTextStream(f)
        stylesheet = ts.readAll()
        if platform.system().lower() == 'darwin':  # see issue #12 on github
            mac_fix = '''
            QDockWidget::title
            {
                background-color: #32414B;
                text-align: center;
                height: 12px;
            }
            '''
            stylesheet += mac_fix
        return stylesheet


def load_stylesheet_pyside():
    """
    Load the stylesheet for use in a pyside application.

    :return the stylesheet string
    """
    warnings.warn(
        "load_stylesheet_pyside() will be deprecated in version 3,"
        "set QtPy environment variable to specify the Qt binding and "
        "use load_stylesheet()",
        PendingDeprecationWarning
    )
    return load_stylesheet(pyside=True)


def load_stylesheet_pyside2():
    """
    Load the stylesheet for use in a pyside2 application.

    :raise NotImplementedError: Because it is not supported yet
    """
    warnings.warn(
        "load_stylesheet_pyside2() will be deprecated in version 3,"
        "set QtPy environment variable to specify the Qt binding and "
        "use load_stylesheet()",
        PendingDeprecationWarning
    )
    return load_stylesheet(pyside=True)


def load_stylesheet_pyqt():
    """
    Load the stylesheet for use in a pyqt4 application.

    :return the stylesheet string
    """
    warnings.warn(
        "load_stylesheet_pyqt() will be deprecated in version 3,"
        "set QtPy environment variable to specify the Qt binding and "
        "use load_stylesheet()",
        PendingDeprecationWarning
    )
    return load_stylesheet(pyside=False)


def load_stylesheet_pyqt5():
    """
    Load the stylesheet for use in a pyqt5 application.

    :param pyside: True to load the pyside rc file, False to load the PyQt rc file

    :return the stylesheet string
    """
    warnings.warn(
        "load_stylesheet_pyqt5() will be deprecated in version 3,"
        "set QtPy environment variable to specify the Qt binding and "
        "use load_stylesheet()",
        PendingDeprecationWarning
    )
    # Smart import of the rc file
    import qdarkstyle.pyqt5_style_rc

    # Load the stylesheet content from resources
    from PyQt5.QtCore import QFile, QTextStream

    f = QFile(":qdarkstyle/style.qss")
    if not f.exists():
        _logger().error("Unable to load stylesheet, file not found in "
                        "resources")
        return ""
    else:
        f.open(QFile.ReadOnly | QFile.Text)
        ts = QTextStream(f)
        stylesheet = ts.readAll()
        if platform.system().lower() == 'darwin':  # see issue #12 on github
            mac_fix = '''
            QDockWidget::title
            {
                background-color: #32414B;
                text-align: center;
                height: 12px;
            }
            '''
            stylesheet += mac_fix
        return stylesheet


def information():
    """Get system and runtime information."""
    info = []
    qt_api = ''
    qt_lib = ''
    qt_bin = ''

    try:
        qt_api = os.environ['QT_API']
    except KeyError:
        qt_api = 'Not set or nonexistent'

    try:
        from Qt import __binding__
    except Exception:
        # It should be (KeyError, ModuleNotFoundError, ImportError)
        # but each python version have a different one, and not define others
        qt_lib = 'Not set or nonexistent'
    else:
        qt_lib = __binding__

    try:
        qt_bin = os.environ['PYQTGRAPH_QT_LIB']
    except KeyError:
        qt_bin = 'Not set or nonexistent'

    info.append('QDarkStyle: %s' % __version__)
    info.append('OS: %s %s %s' % (platform.system(), platform.release(), platform.machine()))
    info.append('Platform: %s' % sys.platform)
    info.append('Python: %s' % '.'.join(str(e) for e in sys.version_info[:]))
    info.append('Python API: %s' % sys.api_version)

    info.append('Binding in use:     %s' % QT_BINDING)
    info.append('Abstraction in use: %s' % QT_ABSTRACTION)

    info.append('qtpy (QT_API):                %s' % qt_api)
    info.append('pyqtgraph (PYQTGRAPH_QT_LIB): %s' % qt_lib)
    info.append('Qt.py (__binding__):          %s' % qt_bin)

    return info


def qt_bindings():
    """Return a list of qt bindings available."""
    return _check_imports(import_list=QT_BINDINGS)


def qt_abstractions():
    """Return a list of qt abstraction layers available."""
    return _check_imports(import_list=QT_ABSTRACTIONS)


def _check_imports(import_list):
    """Return a list of imports available."""

    # Disable warnings here
    warnings.filterwarnings("ignore")

    import_list_return = copy.deepcopy(import_list)
    # Using import_list_return var in for, does not work in py2.7
    # when removing the element, it reflects on for list
    # so it skips next element
    for current_import in import_list:

        spec = True
        # Copy the sys path to make sure to not insert anything
        sys_path = sys.path

        # Check import
        if sys.version_info >= (3, 4):
            spec = importlib.util.find_spec(current_import)
        else:
            try:
                __import__(current_import)
            except RuntimeWarning:
                spec = True
            except Exception:
                spec = None
            else:
                spec = True

        if spec is None:
            # Remove if not available
            import_list_return.remove(current_import)

        # Restore sys path
        sys.path = sys_path

    # Restore warnings
    warnings.resetwarnings()

    return import_list_return


def _import_qt_modules_from(use_binding='pyqt5', use_abstraction='qtpy'):
    """New approach to import modules using importlib."""

    if not sys.version_info >= (3, 4):
        print('Function not available for Python < 3.4')

    spec_binding = importlib.util.find_spec(use_binding)
    spec_abstraction = importlib.util.find_spec(use_abstraction)

    if spec_binding is None:
        print("Cannot find Qt binding: ", use_binding)
    else:
        module = importlib.util.module_from_spec(spec_binding)
        spec.loader.exec_module(module)
        # Adding the module to sys.modules is optional.
        sys.modules[name] = module

    if spec_abstraction is None:
        print("Cannot find Qt abstraction layer: ", use_abstraction)
    else:
        module = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(module)
        # Adding the module to sys.modules is optional.
        sys.modules[name] = module
